@@ -40,10 +40,6 @@ class Consumer(consumer.Consumer):
 
     def __init__(self):
         self.ready_queue = FastQueue()
-        self.ready_queue.put(TaskRequest(mytask.name,
-                                         uuid(),
-                                         args=(2, 2),
-                                         kwargs={}))
         self.timer = Timer()
         self.app = current_app
         self.event_dispatcher = Mock()
@@ -160,8 +156,6 @@ class test_ControlPanel(Case):
         self.panel.handle('report')
 
     def test_active(self):
-        from celery.worker.job import TaskRequest
-
         r = TaskRequest(mytask.name, 'do re mi', (), {})
         state.active_requests.add(r)
         try:
@@ -251,16 +245,22 @@ class test_ControlPanel(Case):
         self.assertTrue(panel.handle('dump_schedule'))
 
     def test_dump_reserved(self):
+        from celery.worker import state
         consumer = Consumer()
-        panel = self.create_panel(consumer=consumer)
-        response = panel.handle('dump_reserved', {'safe': True})
-        self.assertDictContainsSubset({'name': mytask.name,
-                                       'args': (2, 2),
-                                       'kwargs': {},
-                                       'hostname': socket.gethostname()},
-                                       response[0])
-        consumer.ready_queue = FastQueue()
-        self.assertFalse(panel.handle('dump_reserved'))
+        state.reserved_requests.add(TaskRequest(mytask.name,
+                uuid(), args=(2, 2), kwargs={}))
+        try:
+            panel = self.create_panel(consumer=consumer)
+            response = panel.handle('dump_reserved', {'safe': True})
+            self.assertDictContainsSubset({'name': mytask.name,
+                                        'args': (2, 2),
+                                        'kwargs': {},
+                                        'hostname': socket.gethostname()},
+                                        response[0])
+            state.reserved_requests.clear()
+            self.assertFalse(panel.handle('dump_reserved'))
+        finally:
+            state.reserved_requests.clear()
 
     def test_rate_limit_when_disabled(self):
         app = current_app
