@@ -8,6 +8,7 @@
 """
 from __future__ import absolute_import
 
+import os
 import time as _time
 
 from kombu.utils import cached_property
@@ -26,6 +27,9 @@ except ImportError:     # pragma: no cover
     pytz = None         # noqa
 
 
+C_REMDEBUG = os.environ.get('C_REMDEBUG', False)
+
+
 DAYNAMES = 'sun', 'mon', 'tue', 'wed', 'thu', 'fri', 'sat'
 WEEKDAYS = dict((name, dow) for name, dow in zip(DAYNAMES, range(7)))
 
@@ -128,7 +132,7 @@ class _Zone(object):
 
     @cached_property
     def local(self):
-        return tz.tzlocal()
+        return _get_local_timezone()
 
     @cached_property
     def utc(self):
@@ -188,7 +192,7 @@ def delta_resolution(dt, delta):
     return dt
 
 
-def remaining(start, ends_in, now=None, relative=False):
+def remaining(start, ends_in, now=None, relative=False, debug=False):
     """Calculate the remaining time for a start date and a timedelta.
 
     e.g. "how many seconds left for 30 seconds after start?"
@@ -206,7 +210,11 @@ def remaining(start, ends_in, now=None, relative=False):
     end_date = start + ends_in
     if relative:
         end_date = delta_resolution(end_date, ends_in)
-    return end_date - now
+    ret = end_date - now
+    if C_REMDEBUG:
+        print('rem: NOW:%s START:%s END_DATE:%s REM:%s' % (
+            now, start, end_date, ret))
+    return ret
 
 
 def rate(rate):
@@ -237,15 +245,20 @@ def weekday(name):
         raise KeyError(name)
 
 
-def humanize_seconds(secs, prefix=''):
+def humanize_seconds(secs, prefix='', sep=''):
     """Show seconds in human form, e.g. 60 is "1 minute", 7200 is "2
-    hours"."""
+    hours".
+
+    :keyword prefix: Can be used to add a preposition to the output,
+        e.g. 'in' will give 'in 1 second', but add nothing to 'now'.
+
+    """
     secs = float(secs)
     for unit, divider, formatter in TIME_UNITS:
         if secs >= divider:
             w = secs / divider
-            return '%s%s %s' % (prefix, formatter(w),
-                                pluralize(w, unit))
+            return '%s%s%s %s' % (prefix, sep, formatter(w),
+                                  pluralize(w, unit))
     return 'now'
 
 
